@@ -2,7 +2,7 @@ package Bundle::IO::Compress::Bzip2;
 
 use strict;
 
-$Bundle::IO::Compress::Bzip2::VERSION = '2.015';
+$Bundle::IO::Compress::Bzip2::VERSION = '2.017';
 
 
 1;
@@ -21,11 +21,11 @@ Bundle::IO::Compress::Bzip2 - Install IO::Compress::Bzip2 and dependencies
 
 Scalar::Util
 
-IO::Compress::Base 2.015
+Compress::Raw::Bzip2 2.017
 
-Compress::Raw::Bzip2 2.015
+Compress::Raw::Zlib 2.017
 
-IO::Compress::Bzip2 2.015
+IO::Compress::Bzip2 2.017
 
 =head1 AUTHOR
 
@@ -37,7 +37,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2008 Paul Marquess. All rights reserved.
+Copyright (c) 2008-2009 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
